@@ -5,7 +5,7 @@ use warnings;
 
 use utf8;
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 binmode STDERR, ':encoding(UTF-8)';
 binmode STDOUT, ':encoding(UTF-8)';
@@ -37,7 +37,7 @@ if( ! Getopt::Long::GetOptions(
   'o=s' => \$OUTPUT_FILE,
   'terse|t!' => \$params{'terse'},
   'indent|t!' => \$params{'indent'},
-  'escape-unicode|e!' => \$params{'dont-bloody-escape-unicode'},
+  'escape-unicode|e!' => sub { $params{'dont-bloody-escape-unicode'} = $_[1] ? 0 : 1 },
 ) ){ die usage() }
 
 if( defined $INPUT_FILE ){
@@ -48,7 +48,7 @@ if( defined $INPUT_FILE ){
 	$INPUT_STRING = do { local $/; <STDIN> }
 }
 
-my $result = Data::Roundtrip::yaml2perl($INPUT_STRING, \%params);
+my $result = Data::Roundtrip::yaml2dump($INPUT_STRING, \%params);
 if( ! defined $result ){ print STDERR "$0 : error, call to ".'Data::Roundtrip::yaml2perll()'." has failed.\n"; exit(1) }
 
 if( defined $OUTPUT_FILE ){
@@ -71,7 +71,7 @@ yaml2perl.pl : convert YAML data to a Perl variable (dump) which can be parsed o
 
 =head1 VERSION
 
-Version 0.20
+Version 0.21
 
 =head1 SYNOPSIS
 
